pub struct Static { /* private fields */ }Expand description
A static collection of Backends for service discovery.
Implementations
Sourceimpl Static
impl Static
Sourcepub fn new(backends: BTreeSet<Backend>) -> Box<Self>
pub fn new(backends: BTreeSet<Backend>) -> Box<Self>
Create a new boxed Static service discovery with the given backends.
Sourcepub fn try_from_iter<A, T: IntoIterator<Item = A>>(
iter: T,
) -> IoResult<Box<Self>>where
A: ToSocketAddrs,
pub fn try_from_iter<A, T: IntoIterator<Item = A>>(
iter: T,
) -> IoResult<Box<Self>>where
A: ToSocketAddrs,
Create a new boxed Static from a given iterator of items that implements ToSocketAddrs.